guile-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Guile-commits] GNU Guile branch, wip-r6rs-libraries, updated. release_1


From: Julian Graham
Subject: [Guile-commits] GNU Guile branch, wip-r6rs-libraries, updated. release_1-9-8-89-g60c4001
Date: Sat, 27 Mar 2010 19:28:29 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU Guile".

http://git.savannah.gnu.org/cgit/guile.git/commit/?id=60c40014aef5c8025558dd8f060624203222bf50

The branch, wip-r6rs-libraries has been updated
       via  60c40014aef5c8025558dd8f060624203222bf50 (commit)
      from  e084d7a24d0b431750044512379d87be30a1fdff (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 60c40014aef5c8025558dd8f060624203222bf50
Author: Julian Graham <address@hidden>
Date:   Sat Mar 27 15:28:24 2010 -0400

    Implementation for the (rnrs mutable-pairs) and (rnrs mutable-strings)
    libraries.
    
    * module/Makefile.am: Add rnrs/6/mutable-pairs.scm and
      rnrs/6/mutable-strings.scm to RNRS_SOURCES.
    * module/rnrs/6/mutable-pairs.scm: New file.
    * module/rnrs/6/mutable-strings.scm: New file.

-----------------------------------------------------------------------

Summary of changes:
 module/Makefile.am                                 |    2 ++
 module/rnrs/6/{programs.scm => mutable-pairs.scm}  |   10 +++++-----
 .../rnrs/6/{programs.scm => mutable-strings.scm}   |   10 +++++-----
 3 files changed, 12 insertions(+), 10 deletions(-)
 copy module/rnrs/6/{programs.scm => mutable-pairs.scm} (82%)
 copy module/rnrs/6/{programs.scm => mutable-strings.scm} (81%)

diff --git a/module/Makefile.am b/module/Makefile.am
index 2dcba79..a3d9d75 100644
--- a/module/Makefile.am
+++ b/module/Makefile.am
@@ -263,6 +263,8 @@ RNRS_SOURCES =                                      \
   rnrs/6/files.scm                             \
   rnrs/6/hashtables.scm                                \
   rnrs/6/lists.scm                             \
+  rnrs/6/mutable-pairs.scm                     \
+  rnrs/6/mutable-strings.scm                   \
   rnrs/6/programs.scm                          \
   rnrs/6/r5rs.scm                              \
   rnrs/6/sorting.scm                           \
diff --git a/module/rnrs/6/programs.scm b/module/rnrs/6/mutable-pairs.scm
similarity index 82%
copy from module/rnrs/6/programs.scm
copy to module/rnrs/6/mutable-pairs.scm
index 4daa781..3e5da14 100644
--- a/module/rnrs/6/programs.scm
+++ b/module/rnrs/6/mutable-pairs.scm
@@ -1,4 +1,4 @@
 ;;; programs.scm --- The R6RS process management library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.
 ;;
@@ -15,8 +15,8 @@
 ;; You should have received a copy of the GNU Lesser General Public
 ;; License along with this library; if not, write to the Free Software
 ;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
+^L
 
-(library (rnrs programs (6))
-  (export command-line exit)
-  (import (only (guile) command-line exit)))
+(library (rnrs mutable-pairs (6))
+  (export set-car! set-cdr!)
+  (import (only (guile) set-car! set-cdr!)))
@@ -1,4 +1,4 @@
-;;; programs.scm --- The R6RS process management library
+;;; mutable-pairs.scm --- The R6RS mutable pair library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.
diff --git a/module/rnrs/6/programs.scm b/module/rnrs/6/mutable-strings.scm
similarity index 81%
copy from module/rnrs/6/programs.scm
copy to module/rnrs/6/mutable-strings.scm
index 4daa781..1eeb8f3 100644
--- a/module/rnrs/6/programs.scm
+++ b/module/rnrs/6/mutable-strings.scm
@@ -1,4 +1,4 @@
 ;;; programs.scm --- The R6RS process management library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.
 ;;
@@ -15,8 +15,8 @@
 ;; You should have received a copy of the GNU Lesser General Public
 ;; License along with this library; if not, write to the Free Software
 ;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
+^L
 
-(library (rnrs programs (6))
-  (export command-line exit)
-  (import (only (guile) command-line exit)))
+(library (rnrs mutable-strings (6))
+  (export string-set! string-fill!)
+  (import (only (guile) string-set! string-fill!)))
@@ -1,4 +1,4 @@
-;;; programs.scm --- The R6RS process management library
+;;; mutable-strings.scm --- The R6RS mutable string library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.


hooks/post-receive
-- 
GNU Guile




reply via email to

[Prev in Thread] Current Thread [Next in Thread]